CREATE VIEW V_CCS_EDI_SEP12 AS
SELECT SC.COMPUTER_NAME AS 'ComputerName',
                 SC.COMPUTER_DOMAIN_NAME AS 'ComputerDomainName',
                 SC.CURRENT_LOGIN_USER AS 'CurrentLoginUser',
                 SC.OPERATION_SYSTEM AS 'OperatingSystem',
                 SC.PROCESSOR_TYPE AS 'ProcessorType',
                 SC.SERVICE_PACK AS 'ServicePack',
                 SC.IP_ADDR1_TEXT AS 'IPAdress1',
                 SC.IP_ADDR2_TEXT AS 'IPAdress2',
                 G.NAME AS 'GroupName',
                 CASE
                  WHEN SA.STATUS = '1' THEN 'Online' ELSE 'Offline'
                 END AS 'AgentStatus',                
                 SA.AGENT_VERSION AS 'AgentVersion',
                 CONVERT (INT, REPLACE(LEFT(SA.AGENT_VERSION, 6), '.', '')) AS 'AgentVersionInteger',
                 CONVERT (VARCHAR, SA.MAJOR_VERSION) + '.' + CONVERT (VARCHAR, SA.MINOR_VERSION) AS 'AgentVersionMajorMinor',
                 CASE
                  WHEN SA.REBOOT_REQUIRED = 1 THEN 'Yes' ELSE 'No'
                 END AS 'IsRebootRequired',
                 CONVERT (VARCHAR, DATEADD(ss, SA.LAST_UPDATE_TIME / 1000, CAST ('1970-01-01 00:00:00' AS DATETIME)), 101) AS "AgentLastCheckin",           
                 p.version AS 'DefinitionVersion',
                 CONVERT (VARCHAR, CONVERT (DATETIME, Substring(p.version, 0, charindex(' ', p.version)), 101), 101) AS [DefinitionVersionDate],
                 DATEDIFF(d, CONVERT (DATETIME, Substring(p.version, 0, charindex(' ', p.version)), 101), GETDATE()) AS DaysSinceLastDefinitionUpdate,
                 CASE 
                  WHEN DATEDIFF(d, CONVERT (DATETIME, Substring(p.version, 0, charindex(' ', p.version)), 101), GETDATE()) > 7 THEN 'AV Def Overdue' ELSE 'AV Defs Current'
                 END AS 'IsDefinition7DaysOverdueOrNot',
				 CONVERT (VARCHAR, DATEADD(ss, SA.LAST_SCAN_TIME / 1000, CAST ('1970-01-01 00:00:00' AS DATETIME)), 101) AS 'LastScanDate',
				 CASE 
                  WHEN DATEDIFF(d, CONVERT (VARCHAR, DATEADD(ss, SA.LAST_SCAN_TIME / 1000, CAST ('1970-01-01 00:00:00' AS DATETIME)), 101), GETDATE()) > 5 THEN 'Scan Overdue' ELSE 'Scan Current'
                 END AS 'IsLastScanIn5DaysOverdueOrNot',
                 CASE
                  WHEN SA.INFECTED = 1 THEN 'Yes' ELSE 'No'
                 END AS 'MachineIsInfected',
                 CASE
                  WHEN SA.AVENGINE_ONOFF = 1 THEN 'Yes' ELSE 'No'
                 END AS 'AVEngineIsOn',
				 CASE
                  WHEN SA.FIREWALL_ONOFF = 1 THEN 'Yes' ELSE 'No'
                 END AS 'FirewallIsOn',
                 CASE
                  WHEN SA.TAMPER_ONOFF = 1 THEN 'Yes' ELSE 'No'
                 END AS 'TamperProtectionIsOn',
                 CASE
                  WHEN SA.AP_ONOFF = 1 THEN 'Yes' ELSE 'No'
                 END AS 'AutoProtectionIsOn',
                  CASE
                  WHEN SA.PTP_ONOFF = 1 THEN 'Yes' ELSE 'No'
                 END AS 'SonarIsOn',
                 CASE
                  WHEN SA.CIDS_BROWSER_IE_ONOFF = 1 THEN 'Yes' ELSE 'No'
                 END AS 'BrowserIntrusionPreventionIEIsOn',
                 CASE
                  WHEN SA.CIDS_BROWSER_FF_ONOFF = 1 THEN 'Yes' ELSE 'No'
                 END AS 'BrowserIntrusionPreventionFFIsOn',
                 CASE
                  WHEN SA.CIDS_DRV_ONOFF = 1 THEN 'Yes' ELSE 'No'
                 END AS 'IntrusionPreventionIsOn'
                 
FROM   [sem5].[dbo].[SEM_AGENT] AS SA
        INNER JOIN
        [sem5].[dbo].[V_SEM_COMPUTER] AS SC
        ON SC.COMPUTER_ID = SA.COMPUTER_ID
        INNER JOIN
        [sem5].[dbo].[pattern] AS p
        ON sa.pattern_idx = p.pattern_idx
        INNER JOIN
        [sem5].[dbo].V_Groups as g
        ON SA.GROUP_ID = g.ID